@@ -16,9 +16,9 @@ from vivarium.core.registry import (
 # import processes
 from vivarium.processes.meta_division import MetaDivision
 from vivarium.processes.tree_mass import TreeMass
-from vivarium.processes.derive_concentrations import (
-    DeriveConcentrations)
-from vivarium.processes.derive_counts import DeriveCounts
+from vivarium.processes.molarity_deriver import (
+    MolarToCounts,
+    CountsToMolar)
 from vivarium.processes.timeline import TimelineProcess
 from vivarium.processes.clock import Clock
 from vivarium.processes.nonspatial_environment import (
@@ -26,11 +26,14 @@ from vivarium.processes.nonspatial_environment import (
 from vivarium.processes.swap_processes import SwapProcesses
 from vivarium.processes.remove import Remove
 from vivarium.processes.divide_condition import DivideCondition
-from vivarium.processes.mass_adaptor import MassToConcentration, MassToCount
+from vivarium.processes.mass_adaptor import (
+    CountsToConcentration,
+    MassToMolar,
+    MassToCount)
 
 # import updaters, dividers, serializers
 from vivarium.core.registry import (
-    update_accumulate, update_set, update_merge,
+    update_accumulate, update_set, update_merge, update_null,
     update_nonnegative_accumulate, divide_set, divide_split,
     divide_split_dict, divide_zero, assert_no_divide, divide_binomial,
     NumpySerializer, NumpyScalarSerializer, UnitsSerializer,
@@ -44,21 +47,22 @@ _ = plt  # suppress PyCharm's unused-import warning
 process_registry.register(DivideCondition.name, DivideCondition)
 process_registry.register(MetaDivision.name, MetaDivision)
 process_registry.register(TreeMass.name, TreeMass)
-process_registry.register(
-    DeriveConcentrations.name, DeriveConcentrations)
-process_registry.register(DeriveCounts.name, DeriveCounts)
+process_registry.register(MolarToCounts.name, MolarToCounts)
+process_registry.register(CountsToMolar.name, CountsToMolar)
 process_registry.register(TimelineProcess.name, TimelineProcess)
 process_registry.register(
     NonSpatialEnvironment.name, NonSpatialEnvironment)
 process_registry.register(SwapProcesses.name, SwapProcesses)
 process_registry.register(Remove.name, Remove)
 process_registry.register(Clock.name, Clock)
-process_registry.register(MassToConcentration.name, MassToConcentration)
+process_registry.register(CountsToConcentration.name, CountsToConcentration)
 process_registry.register(MassToCount.name, MassToCount)
+process_registry.register(MassToMolar.name, MassToMolar)
 
 # register updaters
 updater_registry.register('accumulate', update_accumulate)
 updater_registry.register('set', update_set)
+updater_registry.register('null', update_null)
 updater_registry.register('merge', update_merge)
 updater_registry.register(
     'nonnegative_accumulate', update_nonnegative_accumulate)
